@@ -2,7 +2,7 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 1997-2016 California Institute of Technology.
-# Copyright (c) 2016-2019 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2022 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/pathos/blob/master/LICENSE
 """
@@ -105,7 +105,7 @@ Other class members:
         """
         object.__init__(self)#, *args, **kwds)
         self.__init(*args, **kwds)
-        self._id = None
+        self._id = kwds.get('id', None)
         return
     def __enter__(self):
         return self
