@@ -2,7 +2,7 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 1997-2016 California Institute of Technology.
-# Copyright (c) 2016-2019 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2022 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/pathos/blob/master/LICENSE
 """
@@ -103,7 +103,9 @@ Mapper that leverages python's multiprocessing.
         self.__nodes = kwds.get('ncpus', cpu_count())
 
         # Create an identifier for the pool
-        self._id = 'pool'
+        self._id = kwds.get('id', None) #'pool'
+        if self._id is None:
+            self._id = self.__nodes
 
         # Create a new server if one isn't already initialized
         self._serve()
