@@ -7,7 +7,7 @@
 # Forked by: Mike McKerns (April 2008)
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2008-2016 California Institute of Technology.
-# Copyright (c) 2016-2019 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2022 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/pathos/blob/master/LICENSE
 #
@@ -175,7 +175,10 @@ NOTE: if a tuple of servers is not provided, defaults to localhost only
        #from _ppserver_config import ppservers as servers # config file
 
         # Create an identifier for the pool
-        self._id = 'server'
+        self._id = kwds.get('id', None) #'server'
+        if self._id is None:
+            _nodes = str(ncpus) if type(ncpus) is int else '*'
+            self._id = '@'.join([_nodes, '+'.join(sorted(servers))])
 
         #XXX: throws 'socket.error' when starting > 1 server with autodetect
         # Create a new server if one isn't already initialized
@@ -244,7 +247,7 @@ NOTE: if a tuple of servers is not provided, defaults to localhost only
             except pp.DestroyedServerError:
                 self._is_alive(None)
         # submit all jobs, then collect results as they become available
-        return (subproc() for subproc in builtins.map(submit, *args))
+        return (subproc() for subproc in list(builtins.map(submit, *args)))
     imap.__doc__ = AbstractWorkerPool.imap.__doc__
     def uimap(self, f, *args, **kwds):
         AbstractWorkerPool._AbstractWorkerPool__imap(self, f, *args, **kwds)
@@ -291,7 +294,10 @@ NOTE: if a tuple of servers is not provided, defaults to localhost only
         nodes = self.nodes
         if self.nodes in ['*','autodetect',None]:
             _pool = self._serve()
-            nodes = _pool.get_ncpus() #XXX: local workers only?
+            nodes = _pool.get_ncpus() #NOTE: local only
+            #nodes = _pool.get_active_nodes() #XXX: ppft version?
+            #nodes = min(j for (i,j) in nodes.items() if i != 'local')
+        if not nodes: nodes = 1
         # try to quickly find a small chunksize that gives good results
         maxsize = 2**62 #XXX: HOPEFULLY, this will never be reached...
         chunksize = 1
