@@ -2,31 +2,29 @@
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
 # Copyright (c) 2015-2016 California Institute of Technology.
-# Copyright (c) 2016-2019 The Uncertainty Quantification Foundation.
+# Copyright (c) 2016-2022 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/pathos/blob/master/LICENSE
 
 from pathos.parallel import *
-from pathos.parallel import __STATE as pstate
-
 from pathos.multiprocessing import *
-from pathos.multiprocessing import __STATE as mstate
-
 from pathos.threading import *
-from pathos.threading import __STATE as tstate
 
 from pathos.helpers import cpu_count
 
 import sys
+import dill
 P33 = (sys.hexversion >= 0x30300f0)
 P37 = (sys.hexversion >= 0x30700f0)
+PYPY38 = (sys.hexversion >= 0x30800f0) and dill._dill.IS_PYPY
 PoolClosedError = ValueError if P33 else AssertionError
 PoolRunningError = ValueError if P37 else AssertionError
 
 def squared(x):
-  return x**2
+    return x**2
 
-def check_basic(pool, state):
+def check_basic(pool):
+    state = pool.__state__
     res = pool.map(squared, range(2))
     assert res == [0, 1]
     res = pool.map(squared, range(2))
@@ -150,7 +148,9 @@ def check_basic(pool, state):
     return
 
 
-def check_nodes(pool, state):
+def check_nodes(pool):
+    state = pool.__state__
+    tag = 'fixed' if pool._id == 'fixed' else None
     new_pool = type(pool)
 
     nodes = cpu_count()
@@ -162,7 +162,7 @@ def check_nodes(pool, state):
     pool.close()
 
     # doesn't create a new pool... IS IT BETTER IF IT DOES?
-    pool = new_pool()
+    pool = new_pool(id=tag)
     try:
         pool.map(squared, range(2))
     except PoolClosedError:
@@ -174,7 +174,7 @@ def check_nodes(pool, state):
     def nnodes(pool):
         return getattr(pool, '_'+new_pool.__name__+'__nodes')
     old_nodes = nnodes(pool)
-    pool = new_pool(nodes=half)
+    pool = new_pool(nodes=half, id=tag)
     new_nodes = nnodes(pool)
     if isinstance(pool, ParallelPool):
         print('SKIPPING: new_pool check for ParallelPool')#FIXME
@@ -191,8 +191,13 @@ def check_nodes(pool, state):
     else:
         raise AssertionError
 
-    # creates a new pool (nodes are different)
-    pool = new_pool()
+    # return to old number of nodes
+    if tag is None:
+        pool.clear() # clear 'half' pool
+        pool = new_pool(id=tag)
+        pool.restart() # restart old pool
+    else: # creates a new pool (update nodes)
+        pool = new_pool(id=tag)
     if isinstance(pool, ParallelPool):
         print('SKIPPING: new_pool check for ParallelPool')#FIXME
     else:
@@ -200,7 +205,7 @@ def check_nodes(pool, state):
         assert res == [0, 1]
     pool.close()
     # doesn't create a new pool... IS IT BETTER IF IT DOES?
-    pool = new_pool()
+    pool = new_pool(id=tag)
     try:
         pool.map(squared, range(2))
     except PoolClosedError:
@@ -211,7 +216,7 @@ def check_nodes(pool, state):
     assert len(state) == 1
     pool.clear()
     assert len(state) == 0
-    pool = new_pool()
+    pool = new_pool(id=tag)
     res = pool.map(squared, range(2))
     assert res == [0, 1]
     assert len(state) == 1
@@ -222,7 +227,8 @@ def check_nodes(pool, state):
     return
 
 
-def check_rename(pool, state):
+def check_rename(pool):
+    state = pool.__state__
     new_pool = type(pool)
     res = pool.map(squared, range(2))
     assert res == [0, 1]
@@ -266,19 +272,25 @@ def check_rename(pool, state):
     return
 
 def test_basic():
-    check_basic(ThreadPool(), tstate)
-#   check_basic(ProcessPool(), mstate)
-#   check_basic(ParallelPool(), pstate)
+    check_basic(ThreadPool())
+#   check_basic(ProcessPool())
+#   check_basic(ParallelPool())
 
 def test_rename():
-    check_rename(ThreadPool(), tstate)
-    check_rename(ProcessPool(), mstate)
-    check_rename(ParallelPool(), pstate)
+    check_rename(ThreadPool())
+    check_rename(ProcessPool())
+    check_rename(ParallelPool())
+
+def test_fixed():
+    check_nodes(ThreadPool(id='fixed'))
+    check_nodes(ProcessPool(id='fixed'))
+    check_nodes(ParallelPool(id='fixed'))
 
 def test_nodes():
-    check_nodes(ThreadPool(), tstate)
-    check_nodes(ProcessPool(), mstate)
-    check_nodes(ParallelPool(), pstate)
+    check_nodes(ThreadPool())
+    if not PYPY38: #FIXME: fails with "OSError: [Errno 24] Too many open files"
+        check_nodes(ProcessPool())
+    check_nodes(ParallelPool())
 
 
 if __name__ == '__main__':
@@ -286,5 +298,6 @@ if __name__ == '__main__':
     freeze_support()
     test_basic()
     test_rename()
+    test_fixed()
     test_nodes()
     shutdown()
